#!/bin/sh

DistributionName="$1"
if [ "$1" != "" ] || [ "$2" != "" ] || [ "$3" != "" ] ; then shift ; fi
VersionName="$1"
if [ "$1" != "" ] || [ "$2" != "" ] || [ "$3" != "" ] ; then shift ; fi
Action="$1"
if [ "$1" != "" ] || [ "$2" != "" ] || [ "$3" != "" ] ; then shift ; fi
Parameters="$@"

Target="/usr/bin/refafit"
RecommendsSoftware="tesseract/tesseract-ocr"
DependsOnSoftware="cat/coreutils gs/ghostscript convert/imagemagick zenity/zenity"

##### IMPORTED FUNCTIONS from ngl-funcions 2016.02.24 #####

Which ()
# Syntax as a funcion: $(Which "$Program")
# Descripcion: Arranged copy of the debianutils' "which" (2009) to not depend of debianutils and not output to stderr (RHEL does it)
# Depends: coreutils
# Depends on functions: (none)
# Notes: There is an alternative to check an executable with path;
#  Example:
#  if test -x /usr/bin/nano && ! test -d /usr/bin/nano ; then echo "TRUE" ; fi
{
	set -ef
	
        puts() {
                printf '%s\n' "$*"
        }
	
	ALLMATCHES=0
	
	while getopts a whichopts
	do
		case "$whichopts" in
			a) ALLMATCHES=1 ;;
			?) puts "Usage: $0 [-a] args"; return 2 ;;
		esac
	done
	shift $(($OPTIND - 1))
	
	if [ "$#" -eq 0 ]; then
		ALLRET=1
	else
		ALLRET=0
	fi
	case $PATH in
		(*[!:]:) PATH="$PATH:" ;;
	esac
	for PROGRAM in "$@"; do
		RET=1
		IFS_SAVE="$IFS"
		IFS=:
		case $PROGRAM in
			*/*)
				if [ -f "$PROGRAM" ] && [ -x "$PROGRAM" ]; then
					puts "$PROGRAM"
					RET=0
				fi
				;;
			*)
				for ELEMENT in $PATH; do
					if [ -z "$ELEMENT" ]; then
						ELEMENT=.
					fi
					if [ -f "$ELEMENT/$PROGRAM" ] && [ -x "$ELEMENT/$PROGRAM" ]; then
						puts "$ELEMENT/$PROGRAM"
						RET=0
						[ "$ALLMATCHES" -eq 1 ] || break
					fi
				done
				;;
		esac
		IFS="$IFS_SAVE"
		if [ "$RET" -ne 0 ]; then
			ALLRET=1
		fi
	done
	
	return "$ALLRET"
}

EsEntero ()
# Sintaxis como función: EsEntero $Valor
# Description: Devuelve (result) true si el valor es numérico entero, y false en caso contrario. (IsNumeric/EsNumerico)
# Ejemplo de uso (sin corchetes []):
#	if EsEntero $Respuesta ; then echo "Correcto." ; fi
# Depends on functions: (none)
# Depends on other software: coreutils
{
    [ "$1" -eq "$1" ] > /dev/null 2>&1
    return $?
}

NumeroResumit ()
# Sintaxi com a funció: $(NumeroResumit $Numero $Estil)
# Retorna el número humanament llegible, segons $Estil:
# 	"2" :	Amb factors de 1024 (10,5b; 10,5k; 10,5m; 10,5g)
# 	"2L" :	Amb factors de 1024 i notació llarga (10,5B; 10,5KiB; 10,5MiB; 10,5GiB)
# 	"1" :	Amb factors de 1000 (10,5B; 10,5K; 10,5M; 10,5G) (SI)
# 	"." :	Utilitzar el separador decimal "." en comptes del predeterminat ","
#	Si s'afegeix un espai, se separa el número de la notació amb un espai:
#		"2 "	10,5 g
#		"2L "	9,5 MiB
#		"1 "	8300,5 B
#	Si s'afegeix una "A", aleshores s'alineen les dades:
#		"A2"	  10,5g
#		"A2L"	   9,5MiB
#		"A1"	8300,5B
#	Si s'afegeix un "0", aleshores no s'expressen decimals (només l'enter arrodonit a la baixa):
#		"02"	10g
#		"02L"	9MiB
#		"01"	8300B
#	Tot es pot combinar:
#		"A02L "	   9 MiB
#		"A01L "	8300 B
#		"2L."	9.5MiB
# Nota: el $Numero s'espera en bytes (octets)
# Depends on functions: (none)
# Depends on other software: grep
{
	local Numero=$1
	local Estil="$2"
	local LlindarResum=2000
	local SimbolDecimal=","
	local EnterVisible=""
	local DecimalVisible=""
	local Sufix=""
	local Factor=0
	
	if [ "$(echo "$Estil" | grep "\.")" != "" ] ; then SimbolDecimal="." ; fi
	if [ "$(echo "$Estil" | grep "2")" != "" ] ; then
		Factor=1024
	else
		if [ "$(echo "$Estil" | grep "1")" != "" ] ; then
			Factor=1000
		else
			return 1
		fi
	fi
	EnterVisible="$Numero"
	Sufix="B"
	# Resum
	if [ $Numero -ge $LlindarResum ] ; then
		EnterVisible="$(($Numero / $Factor))"
		DecimalVisible="$(($(($(($Numero * 10)) / $Factor)) % 10))"
		Numero=$(($Numero / $Factor))
		Sufix="K"
		if [ $Numero -ge $LlindarResum ] ; then
			EnterVisible="$(($Numero / $Factor))"
			DecimalVisible="$(($(($(($Numero * 10)) / $Factor)) % 10))"
			Numero=$(($Numero / $Factor))
			Sufix="M"
			if [ $Numero -ge $LlindarResum ] ; then
				EnterVisible="$(($Numero / $Factor))"
				DecimalVisible="$(($(($(($Numero * 10)) / $Factor)) % 10))"
				Numero=$(($Numero / $Factor))
				Sufix="G"
				if [ $Numero -ge $LlindarResum ] ; then
					EnterVisible="$(($Numero / $Factor))"
					DecimalVisible="$(($(($(($Numero * 10)) / $Factor)) % 10))"
					Numero=$(($Numero / $Factor))
					Sufix="T"
					if [ $Numero -ge $LlindarResum ] ; then
						EnterVisible="$(($Numero / $Factor))"
						DecimalVisible="$(($(($(($Numero * 10)) / $Factor)) % 10))"
						Numero=$(($Numero / $Factor))
						Sufix="P"
						if [ $Numero -ge $LlindarResum ] ; then
							EnterVisible="$(($Numero / $Factor))"
							DecimalVisible="$(($(($(($Numero * 10)) / $Factor)) % 10))"
							Numero=$(($Numero / $Factor))
							Sufix="E"
							if [ $Numero -ge $LlindarResum ] ; then
								EnterVisible="$(($Numero / $Factor))"
								DecimalVisible="$(($(($(($Numero * 10)) / $Factor)) % 10))"
								Numero=$(($Numero / $Factor))
								Sufix="Z"
								if [ $Numero -ge $LlindarResum ] ; then
									EnterVisible="$(($Numero / $Factor))"
									DecimalVisible="$(($(($(($Numero * 10)) / $Factor)) % 10))"
									Numero=$(($Numero / $Factor))
									Sufix="Y"
								fi
							fi
						fi
					fi
				fi
			fi
		fi
	fi
	# Decimal invisible
	if [ "$(echo "$Estil" | grep "0")" != "" ] ; then
		DecimalVisible=""
	else
		if [ "$DecimalVisible" = "" ] ; then DecimalVisible="0" ; fi
		DecimalVisible="$SimbolDecimal$DecimalVisible"
	fi
	# Notació llarga
	if [ "$(echo "$Estil" | grep "2")" != "" ] ; then  # factor binari, sufix en minuscula
		case "$Sufix" in
			"B" )	Sufix="b"	;;
			"K" )	Sufix="k"	;;
			"M" )	Sufix="m"	;;
			"G" )	Sufix="g"	;;
			"T" )	Sufix="t"	;;
			"P" )	Sufix="p"	;;
			"E" )	Sufix="e"	;;
			"Z" )	Sufix="z"	;;
			"Y" )	Sufix="y"	;;
		esac
		if [ "$(echo "$Estil" | grep "L")" != "" ] ; then
			case "$Sufix" in
				"b" )	if [ "$(echo "$Estil" | grep "A")" != "" ] ; then
						Sufix="B  "	# Amb aliniació
					else
						Sufix="B"
					fi
					;;
				"k" )	Sufix="KiB"	;;
				"m" )	Sufix="MiB"	;;
				"g" )	Sufix="GiB"	;;
				"t" )	Sufix="TiB"	;;
				"p" )	Sufix="PiB"	;;
				"e" )	Sufix="EiB"	;;
				"z" )	Sufix="ZiB"	;;
				"y" )	Sufix="YiB"	;;
			esac
		fi
	fi
	# Espai
	if [ "$(echo "$Estil" | grep " ")" != "" ] ; then
		Sufix=" $Sufix"
	fi
	# Aliniació
	if [ "$(echo "$Estil" | grep "A")" != "" ] ; then
		while [ ${#EnterVisible} -lt 4 ] ; do
			EnterVisible=" $EnterVisible"
		done
	fi
	echo "$EnterVisible$DecimalVisible$Sufix"
}

DependenciasFaltan ()
# Sintaxis como función: $(DependenciasFaltan "$ListaDependencias")
# Descripción:
#	Comprueba la disponibilidad de los programas especificados y
#	devuelve (echo) una lista de los que faltan. Si se encuentra todo
#	no devuelve nada.
# Parámetros esperados:
#	$1	Lista separada por espacios de cada ejecutable y paquete respectivo,
#		separados entre si por "/"
#		Para varias opciones de ejecutable, separarlos entre ":"
# Depends on functions: Which
# Depends on other software: coreutils
# Ejemplo1:	$(DependenciasFaltan "cat/coreutils grep/grep dpkg-deb/dpkg")
#		puede devolver "grep dpkg[dpkg-deb]" si faltan grep y dpkg-deb
# Ejemplo2:	$(DependenciasFaltan "insserv:update-rc.d/sysv-rc cat/coreutils")
#		puede devolver "sysv-rc[update-rc.d]" si tanto falta insserv como update-rc.d
{
	local ListaDependencias="$1"
	local DependenciaActual=""
	local EjecutablesActuales=""
	local EjecutableActual=""
	local EncontradoActual=""
	local PaqueteActual=""
	local Valor=""
	
	for DependenciaActual in $ListaDependencias ; do
		EjecutablesActuales="$(echo "$DependenciaActual" | cut -f 1 -d "/")"
		PaqueteActual="$(echo "$DependenciaActual" | cut -f 2 -d "/")"
		EjecutablesActuales="$(echo "$EjecutablesActuales" | tr -s ":" " ")"
		EncontradoActual=""
		for EjecutableActual in $EjecutablesActuales ; do
			if [ "$(Which "$EjecutableActual")" != "" ] ; then
				EncontradoActual="1"
			fi
		done
		if [ "$EncontradoActual" = "" ] ; then
			if [ "$(echo " $Valor " | grep -e " $PaqueteActual\[")" = "" ] || [ "$(echo " $Valor " | grep -e " $PaqueteActual ")" = "" ] ; then
				if [ "$EjecutableActual" = "$PaqueteActual" ] || [ "$EjecutableActual" != "$EjecutablesActuales" ] ; then
					Valor="$Valor $PaqueteActual"
				else
					Valor="$Valor $PaqueteActual[$EjecutableActual]"
				fi
			fi
		fi
	done
	if [ "$Valor" != "" ] ; then
		echo $Valor
	fi
}

DfOutputValue ()
# Description: Parser for DF command, that emulates --output option for old versions without support for it. Only returns (echo) the one asked output value.
# Notes:
#	- Sizes are returned in bytes.
# Depends on functions: (none)
# Depends on other software: 
{
	local OutputField="$1"
	local Path="$2"
	local LineInodes=""
	local LineSpace=""
	local WordsInodes=""
	local WordsSpace=""
	local Result=0
	local Value=""
	
	if [ "$(df --help | grep -e '--output')" != "" ] ; then
		df "--output=${OutputField}" "$Path" >/dev/null 2>&1
		Result=$?
		if [ $Result -eq 0 ] ; then
			Value="$(env LANG=en df --block-size=1 "--output=${OutputField}" "$Path" 2>/dev/null | tail -n 1)"
		fi
	else
		df -P "$Path" >/dev/null 2>&1
		Result=$?
		if [ $Result -eq 0 ] ; then
			# Note: Different GNU distributions have complete different alignment policy.
			#       Most of fields is better to get counting words backwards since the common % symbol.
			#	This method is incompatible with devices with % symbol in path.
			LineInodes="$(env LANG=en df -PTi "$Path" | tail -n 1)"
			LineSpace="$(env LANG=en df -PT --block-size=1 "$Path" | tail -n 1)"
			if [ "$(echo "$LineInodes" | grep -e '%')" = "" ] ; then
				# Optical media
				LineInodes="$(echo "$LineInodes" | sed -e 's| - | 100% |g')"
			fi
			WordsInodes=$(echo $LineInodes | cut -f 2- -d ' ' | cut -f 1 -d '%' | sed -e 's| |\n|g')
			WordsSpace=$(echo $LineSpace | cut -f 2- -d ' ' | cut -f 1 -d '%' | sed -e 's| |\n|g')
			case "$OutputField" in
				"source" )
					Value=$(echo "$WordsInodes" | tail -n 5 | head -n 1)	# Get fstype to use as field splitter
					Value="$(echo "$LineInodes" | sed -e "s| ${Value} |\n|g" | head -n 1)"
					;;
				"fstype" )
					Value=$(echo "$WordsInodes" | tail -n 5 | head -n 1)
					;;
				"itotal" )
					Value=$(echo "$WordsInodes" | tail -n 4 | head -n 1)
					;;
				"iused" )
					Value=$(echo "$WordsInodes" | tail -n 3 | head -n 1)
					;;
				"iavail" )
					Value=$(echo "$WordsInodes" | tail -n 2 | head -n 1)
					;;
				"ipcent" )
					Value=$(echo $LineInodes | cut -f 2- -d ' ' | sed -e 's| |\n|g' | grep -e '%' | head -n 1)
					;;
				"size" )
					Value=$(echo "$WordsSpace" | tail -n 4 | head -n 1)
					;;
				"used" )
					Value=$(echo "$WordsSpace" | tail -n 3 | head -n 1)
					;;
				"avail" )
					Value=$(echo "$WordsSpace" | tail -n 2 | head -n 1)
					;;
				"pcent" )
					Value=$(echo $LineSpace | cut -f 2- -d ' ' | sed -e 's| |\n|g' | grep -e '%' | head -n 1)
					;;
				"target" )
					Value=$(echo $LineInodes | cut -f 2- -d ' ' | cut -f 2- -d '%')
					;;
			esac
		fi
	fi
	if [ "$Value" != "" ] ; then
		if [ "$OutputField" = "source" ] && [ "$(echo "$Value" | grep -e '^/')" != "" ] && [ "$(readlink -f "$Value" 2>/dev/null)" != "" ] ; then
			Value="$(readlink -f "$Value")"
		fi
		# Trim:
		Value="$(expr "$Value" : "[ ]*\(.*[^ ]\)[ ]*$")"
		echo "$Value"
	fi
}

DiscoLibre ()
# Sintaxis como funcion: $(DiscoLibre "$Path" "$Unit")
# Descripcion: Devuelve el espacio libre en una ruta dada
# Parametros esperados:
#	$1	Ruta a analizar (directorio)
#	$2	Unidad de medida: "B"=bytes "K"=KBytes "M"=MBytes "G"=GBytes "H"=Humanamente legible y con sufijo
# Notas:	- Devuelve el valor con echo.
#		- Si no se encuentra la ruta, no devuelve nada.
# Depends on functions: DfOutputValue EsEntero NumeroResumit
# Depends on other software: 
{
	local Path="$1"
	local Unit="$2"
	local Value=0
	
	if [ -d "$Path" ] ; then
		Value="$(DfOutputValue target "$Path")"
		if [ "$Value" != "/dev" ] ; then
			Value="$(DfOutputValue avail "$Path")"
		fi
		if EsEntero $Value ; then
			case "$Unit" in
				"B" ) Value="${Value}" ;;
				"b" ) Value="${Value}" ;;
				"K" ) Value="$(($Value / 1024))" ;;
				"k" ) Value="$(($Value / 1024))" ;;
				"M" ) Value="$(($Value / 1024 / 1024))" ;;
				"m" ) Value="$(($Value / 1024 / 1024))" ;;
				"G" ) Value="$(($Value / 1024 / 1024 / 1024))" ;;
				"g" ) Value="$(($Value / 1024 / 1024 / 1024))" ;;
				"T" ) Value="$(($Value / 1024 / 1024 / 1024 / 1024))" ;;
				"t" ) Value="$(($Value / 1024 / 1024 / 1024 / 1024))" ;;
				"P" ) Value="$(($Value / 1024 / 1024 / 1024 / 1024 / 1024))" ;;
				"p" ) Value="$(($Value / 1024 / 1024 / 1024 / 1024 / 1024))" ;;
				"E" ) Value="$(($Value / 1024 / 1024 / 1024 / 1024 / 1024 / 1024))" ;;
				"e" ) Value="$(($Value / 1024 / 1024 / 1024 / 1024 / 1024 / 1024))" ;;
				"Z" ) Value="$(($Value / 1024 / 1024 / 1024 / 1024 / 1024 / 1024 / 1024))" ;;
				"z" ) Value="$(($Value / 1024 / 1024 / 1024 / 1024 / 1024 / 1024 / 1024))" ;;
				"Y" ) Value="$(($Value / 1024 / 1024 / 1024 / 1024 / 1024 / 1024 / 1024 / 1024))" ;;
				"y" ) Value="$(($Value / 1024 / 1024 / 1024 / 1024 / 1024 / 1024 / 1024 / 1024))" ;;
				* ) Value="$(NumeroResumit $Value '02L')" ;;
			esac
			echo $Value
		fi
	fi
}


##### SPECIFIC FUNCTIONS TO THIS SCRIPT #####

##### MAIN SCRIPT #####

Result=0
ResultN=0

case "$Action" in
	"install" )
		LackDependencies="$(DependenciasFaltan "$DependsOnSoftware")"	#"
		if [ "$LackDependencies" != "" ] ; then
			echo "ERROR: Following software must be installed before this dependent service:" 1>&2
			echo "       $LackDependencies" 1>&2
			Result=1 ; if [ $ResultN -eq 0 ] ; then ResultN=$Result ; fi
		fi
		if [ $ResultN -eq 0 ] ; then
			LackRecommends="$(DependenciasFaltan "$RecommendsSoftware")"	#"
			if [ "$LackRecommends" != "" ] ; then
				echo "WARNING: Following software is recommended for full features:" 1>&2
				echo "       $LackRecommends" 1>&2
			fi
			# Remove old names
			rm -f "/usr/bin/resamplepdf"
			xdg-desktop-menu uninstall --mode system actiu-resamplepdf-combined.desktop
			xdg-desktop-menu uninstall --mode system actiu-resamplepdf-textscan.desktop
			# Install new
			if [ "$(which zenity)" = "" ] ; then
				apt-get install -y --force-yes zenity
				Result=$? ; if [ $ResultN -eq 0 ] ; then ResultN=$Result ; fi
			fi
			if [ "$(which gs)" = "" ] ; then
				apt-get install -y --force-yes ghostscript
				Result=$? ; if [ $ResultN -eq 0 ] ; then ResultN=$Result ; fi
			fi
			if [ "$(which convert)" = "" ] ; then
				apt-get install -y --force-yes imagemagick
				Result=$? ; if [ $ResultN -eq 0 ] ; then ResultN=$Result ; fi
			fi
			if [ "$(which tesseract)" = "" ] ; then
				if [ $(DiscoLibre /usr/share G) -ge 10 ] ; then
					# OCR for english, spanish and catalan (80 MiB)
					apt-get install -y --force-yes tesseract-ocr tesseract-ocr-cat tesseract-ocr-spa
					Result=$? ; if [ $ResultN -eq 0 ] ; then ResultN=$Result ; fi
					if [ $Result -eq 0 ] ; then
						if [ $(DiscoLibre /usr/share G) -ge 20 ] ; then
							# OCR for all languages (>600 MiB)
							apt-get install -y --force-yes $(apt-cache search tesseract-ocr | grep -e '^tesseract-ocr-' | cut -f 1 -d ' ')
						fi
					fi
				fi
			fi
			if [ "$(which nautilus-actions-new)" = "" ] && [ "$(which nautilus)" != "" ] ; then
				apt-get install -y --force-yes nautilus-actions
				Result=$? ; if [ $ResultN -eq 0 ] ; then ResultN=$Result ; fi
			fi
			cp refafit "$Target"
			Result=$? ; if [ $ResultN -eq 0 ] ; then ResultN=$Result ; fi
			if [ $ResultN -ne 0 ] ; then
				rm -f "$Target"
			fi
		fi
		if [ $ResultN -eq 0 ] ; then
			chown root:root "$Target"
			chmod u=rwx,go=rx "$Target"
			# Associacions de fitxer
			MimesToInstall="$(cat *.desktop | grep -ie '^MimeType=' | cut -f 2- -d '=' | sed -e 's|;|\n|g')"
			PdfMimeType="$(file --mime-type --brief mime-sample.pdf)"
			if [ "$PdfMimeType" != "" ] ; then
				MimesToInstall="$(echo "$MimesToInstall" ; echo "$PdfMimeType")"	#"
			fi
			MimesToInstall="$(echo "$MimesToInstall" | sort --unique)"
			mkdir -p /etc/skel/.peinddd
			SkelRestorator="/etc/skel/.peinddd/refafit_restoremimes.sh"
			echo '#!/bin/sh' > "$SkelRestorator"
			echo '#!/bin/sh' > "$SkelRestorator"
			echo '' >> "$SkelRestorator"
			echo 'PatchMimePath ()' >> "$SkelRestorator"
			echo '{' >> "$SkelRestorator"
			echo '	# In some distribution/version xdg-mime fails because of lack of ~/.local/share/applications/' >> "$SkelRestorator"
			echo '	local ApplicationLauncher="$1"' >> "$SkelRestorator"
			echo '	local MimeType="$2"' >> "$SkelRestorator"
			echo '' >> "$SkelRestorator"	
			echo '	if [ "$MimeType" != "" ] && [ "$MimePathPatched" != "1" ] ; then' >> "$SkelRestorator"
			echo '		Test="$(env LANG=en xdg-mime default "$ApplicationLauncher" "$MimeType" 2>&1)"' >> "$SkelRestorator"
			echo '		if [ "$(echo "$Test" | grep -ie "cannot touch")" ] ; then' >> "$SkelRestorator"
			echo "			Test=\"\$(echo \"$Test\" | grep -ie \"cannot touch\" | cut -f 2 -d \"'\")\"" >> "$SkelRestorator"
			echo '			echo "\$ mkdir -p \"$(dirname "$Test")\""' >> "$SkelRestorator"
			echo '			mkdir -p "$(dirname "$Test")"' >> "$SkelRestorator"
			echo '			MimePathPatched=1' >> "$SkelRestorator"
			echo '		fi' >> "$SkelRestorator"
			echo '	fi' >> "$SkelRestorator"
			echo '}' >> "$SkelRestorator"
			echo '' >> "$SkelRestorator"
			IFS="$(printf "\n\b")" ; for CurrentMime in $MimesToInstall ; do unset IFS	#"
				CurrentApplication="$(xdg-mime query default "$CurrentMime")"	#"
				if [ "$CurrentApplication" != "" ] ; then
					if [ "$MimePathPatched" != "1" ] ; then
						echo "PatchMimePath \"${CurrentApplication}\" \"$CurrentMime\"" >> "$SkelRestorator"
						MimePathPatched=1
					fi
					echo "xdg-mime default \"${CurrentApplication}\" \"$CurrentMime\"" >> "$SkelRestorator"
				fi
			done
			chmod a+rx "$SkelRestorator"
			if [ "$PdfMimeType" != "" ] && [ "$(echo "$PdfMimeType" | grep -ie 'stream')" = "" ] && [ "$(echo "$PdfMimeType" | grep -ie 'empty')" = "" ] ; then
				PdfMimeType="$(echo "$PdfMimeType" | sed -e 's/\//\\\//g')"
				cat actiu-refafit-pdfcombined.desktop | sed -e "s/MimeType=.*/MimeType=${PdfMimeType};/g" > /tmp/actiu-refafit-pdfcombined.desktop
				cat actiu-refafit-pdftextscan.desktop | sed -e "s/MimeType=.*/MimeType=${PdfMimeType};/g" > /tmp/actiu-refafit-pdftextscan.desktop
				cat actiu-refafit-joinpdfs.desktop | sed -e "s/MimeType=.*/MimeType=${PdfMimeType};/g" > /tmp/actiu-refafit-joinpdfs.desktop
				cat actiu-refafit-splitpdfpages.desktop | sed -e "s/MimeType=.*/MimeType=${PdfMimeType};/g" > /tmp/actiu-refafit-splitpdfpages.desktop
			else
				cat actiu-refafit-pdfcombined.desktop > /tmp/actiu-refafit-pdfcombined.desktop
				cat actiu-refafit-pdftextscan.desktop > /tmp/actiu-refafit-pdftextscan.desktop
				cat actiu-refafit-joinpdfs.desktop > /tmp/actiu-refafit-joinpdfs.desktop
				cat actiu-refafit-splitpdfpages.desktop > /tmp/actiu-refafit-splitpdfpages.desktop
			fi
			# Instal·lar llançadores d'aplicació:
			# (amb els tipus MIME especificats al fitxer .desktop ja serveix com a aplicació addicional)
			chmod a+r /tmp/actiu-refafit-pdfcombined.desktop
			xdg-desktop-menu install --mode system /tmp/actiu-refafit-pdfcombined.desktop
			chmod a+r /tmp/actiu-refafit-pdftextscan.desktop
			xdg-desktop-menu install --mode system /tmp/actiu-refafit-pdftextscan.desktop
			chmod a+r /tmp/actiu-refafit-joinpdfs.desktop
			xdg-desktop-menu install --mode system /tmp/actiu-refafit-joinpdfs.desktop
			chmod a+r /tmp/actiu-refafit-splitpdfpages.desktop
			xdg-desktop-menu install --mode system /tmp/actiu-refafit-splitpdfpages.desktop
			chmod a+r actiu-refafit-directorytopdf.desktop
			xdg-desktop-menu install --mode system actiu-refafit-directorytopdf.desktop
			chmod a+r actiu-refafit-imagestopdf.desktop
			xdg-desktop-menu install --mode system actiu-refafit-imagestopdf.desktop
			chmod a+r actiu-refafit-ocr.desktop
			xdg-desktop-menu install --mode system actiu-refafit-ocr.desktop
			Result=$? ; if [ $ResultN -eq 0 ] ; then ResultN=$Result ; fi
			rm /tmp/actiu-refafit-pdfcombined.desktop
			rm /tmp/actiu-refafit-pdftextscan.desktop
			rm /tmp/actiu-refafit-joinpdfs.desktop
			rm /tmp/actiu-refafit-splitpdfpages.desktop
			rm -f /etc/skel/.peinddd/refafit_restoremimes.sh
		fi
		;;
	"remove" | "purge" )
		xdg-desktop-menu uninstall --mode system actiu-resamplepdf-combined.desktop
		xdg-desktop-menu uninstall --mode system actiu-resamplepdf-textscan.desktop
		xdg-desktop-menu uninstall --mode system actiu-refafit-pdfcombined.desktop
		xdg-desktop-menu uninstall --mode system actiu-refafit-joinpdfs.desktop
		xdg-desktop-menu uninstall --mode system actiu-refafit-splitpdfpages.desktop
		xdg-desktop-menu uninstall --mode system actiu-refafit-pdftextscan.desktop
		xdg-desktop-menu uninstall --mode system actiu-refafit-directorytopdf.desktop
		xdg-desktop-menu uninstall --mode system actiu-refafit-imagestopdf.desktop
		xdg-desktop-menu uninstall --mode system actiu-refafit-ocr.desktop
		Result=$? ; if [ $ResultN -eq 0 ] ; then ResultN=$Result ; fi
		rm -f "$Target"
		Result=$? ; if [ $ResultN -eq 0 ] ; then ResultN=$Result ; fi
		;;
	* )
		Result=1 ; if [ $ResultN -eq 0 ] ; then ResultN=$Result ; fi
		echo "ERROR: Unknown action ($Action)"
		;;
esac

exit $ResultN
